@@ -6,7 +6,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "../../../../../src/avogadro-1.1.1/libavogadro/src/extensions/crystallography/crystallographyextension.h"
+#include "../../../../../src/avogadro-1.2.0/libavogadro/src/extensions/crystallography/crystallographyextension.h"
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'crystallographyextension.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 63
@@ -22,7 +22,7 @@ static const uint qt_meta_data_Avogadro__CrystallographyExtension[] = {
        6,       // revision
        0,       // classname
        0,    0, // classinfo
-      94,   14, // methods
+      98,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -85,47 +85,51 @@ static const uint qt_meta_data_Avogadro__CrystallographyExtension[] = {
     1586, 1579,   35,   35, 0x0a,
     1611,   35,   35,   35, 0x0a,
     1626,   35,   35,   35, 0x0a,
-    1653, 1644,   35,   35, 0x0a,
-    1684,   35,   35,   35, 0x0a,
-    1699,   35,   35,   35, 0x0a,
-    1719, 1716,  754,   35, 0x0a,
-    1779, 1774,   35,   35, 0x0a,
-    1809,   35, 1804,   35, 0x0a,
-    1824,   35,   35,   35, 0x0a,
-    1843,   35,   35,   35, 0x0a,
-    1862,   35,   35,   35, 0x08,
-    1880,   35,   35,   35, 0x08,
-    1907,   35,   35,   35, 0x08,
-    1929,   35,   35,   35, 0x08,
-    1950,   35,   35,   35, 0x08,
-    1976,   35,   35,   35, 0x08,
-    2000,   35,   35,   35, 0x08,
-    2021,   35,   35,   35, 0x08,
-    2044,   35,   35,   35, 0x08,
-    2062,   35,   35,   35, 0x08,
-    2083,   35,   35,   35, 0x08,
-    2105,   35,   35,   35, 0x08,
-    2130,   35,   35,   35, 0x08,
-    2148,   35,   35,   35, 0x08,
-    2171,   35,   35,   35, 0x08,
-    2191,   35,   35,   35, 0x08,
-    2214,   35,   35,   35, 0x08,
-    2236,   35,   35,   35, 0x08,
-    2264,   35,   35,   35, 0x08,
-    2288,   35,   35,   35, 0x08,
-    2317,   35,   35,   35, 0x08,
-    2346,   35,   35,   35, 0x08,
-    2371,   35,   35,   35, 0x08,
-    2396,   35,   35,   35, 0x08,
-    2415,   35,   35,   35, 0x08,
-    2434,   35,   35,   35, 0x08,
-    2461,   35,   35,   35, 0x08,
-    2488,   35,   35,   35, 0x08,
-    2507,   35,   35,   35, 0x08,
-    2526,   35,   35,   35, 0x08,
-    2551,   35,   35,   35, 0x08,
-    2579,   35,   35,   35, 0x08,
-    2608,   35,   35,   35, 0x08,
+    1651,   35,   35,   35, 0x0a,
+    1678, 1669,   35,   35, 0x0a,
+    1709,   35,   35,   35, 0x0a,
+    1724,   35,   35,   35, 0x0a,
+    1744, 1741,  754,   35, 0x0a,
+    1804, 1799,   35,   35, 0x0a,
+    1834,   35, 1829,   35, 0x0a,
+    1849,   35,   35,   35, 0x0a,
+    1868,   35,   35,   35, 0x0a,
+    1887,   35,   35,   35, 0x08,
+    1905,   35,   35,   35, 0x08,
+    1932,   35,   35,   35, 0x08,
+    1954,   35,   35,   35, 0x08,
+    1975,   35,   35,   35, 0x08,
+    2015, 2006,   35,   35, 0x08,
+    2045,   35,   35,   35, 0x28,
+    2071,   35,   35,   35, 0x08,
+    2095,   35,   35,   35, 0x08,
+    2116,   35,   35,   35, 0x08,
+    2139,   35,   35,   35, 0x08,
+    2157,   35,   35,   35, 0x08,
+    2178,   35,   35,   35, 0x08,
+    2200,   35,   35,   35, 0x08,
+    2225,   35,   35,   35, 0x08,
+    2243,   35,   35,   35, 0x08,
+    2266,   35,   35,   35, 0x08,
+    2286,   35,   35,   35, 0x08,
+    2309,   35,   35,   35, 0x08,
+    2331,   35,   35,   35, 0x08,
+    2359,   35,   35,   35, 0x08,
+    2383,   35,   35,   35, 0x08,
+    2412,   35,   35,   35, 0x08,
+    2441,   35,   35,   35, 0x08,
+    2466,   35,   35,   35, 0x08,
+    2491,   35,   35,   35, 0x08,
+    2510,   35,   35,   35, 0x08,
+    2529,   35,   35,   35, 0x08,
+    2556,   35,   35,   35, 0x08,
+    2583,   35,   35,   35, 0x08,
+    2602,   35,   35,   35, 0x08,
+    2621,   35,   35,   35, 0x08,
+    2646,   35,   35,   35, 0x08,
+    2674,   35,   35,   35, 0x08,
+    2695,   35,   35,   35, 0x08,
+    2724,   35,   35,   35, 0x08,
 
        0        // eod
 };
@@ -176,8 +180,9 @@ static const char qt_meta_stringdata_Avogadro__CrystallographyExtension[] = {
     "ids,coords\0"
     "setCurrentCartesianCoords(QList<QString>,QList<Eigen::Vector3d>)\0"
     "volume\0setCurrentVolume(double)\0"
-    "fillUnitCell()\0wrapAtomsToCell()\0"
-    "v1,v2,v3\0buildSuperCell(uint,uint,uint)\0"
+    "fillUnitCell()\0reduceToAsymmetricUnit()\0"
+    "wrapAtomsToCell()\0v1,v2,v3\0"
+    "buildSuperCell(uint,uint,uint)\0"
     "rebuildBonds()\0orientStandard()\0in\0"
     "rotateCellMatrixToStandardOrientation(Eigen::Matrix3d)\0"
     "text\0showPasteDialog(QString)\0bool\0"
@@ -185,6 +190,8 @@ static const char qt_meta_stringdata_Avogadro__CrystallographyExtension[] = {
     "hideUnitCellAxes()\0refreshEditors_()\0"
     "actionPerceiveSpacegroup()\0"
     "actionSetSpacegroup()\0actionFillUnitCell()\0"
+    "actionReduceToAsymmetricUnit()\0skipUndo\0"
+    "actionSymmetrizeCrystal(bool)\0"
     "actionSymmetrizeCrystal()\0"
     "actionPrimitiveReduce()\0actionNiggliReduce()\0"
     "actionToggleUnitCell()\0actionBuildSlab()\0"
@@ -203,7 +210,7 @@ static const char qt_meta_stringdata_Avogadro__CrystallographyExtension[] = {
     "actionMatrixCart()\0actionMatrixFrac()\0"
     "actionMatrixRowVectors()\0"
     "actionMatrixColumnVectors()\0"
-    "cacheFractionalCoordinates()\0"
+    "actionSpgTolerance()\0cacheFractionalCoordinates()\0"
     "restoreFractionalCoordinates()\0"
 };
 
@@ -286,50 +293,54 @@ void Avogadro::CrystallographyExtension::qt_static_metacall(QObject *_o, QMetaOb
         case 49: _t->setCurrentCartesianCoords((*reinterpret_cast< const QList<QString>(*)>(_a[1])),(*reinterpret_cast< const QList<Eigen::Vector3d>(*)>(_a[2]))); break;
         case 50: _t->setCurrentVolume((*reinterpret_cast< double(*)>(_a[1]))); break;
         case 51: _t->fillUnitCell(); break;
-        case 52: _t->wrapAtomsToCell(); break;
-        case 53: _t->buildSuperCell((*reinterpret_cast< const uint(*)>(_a[1])),(*reinterpret_cast< const uint(*)>(_a[2])),(*reinterpret_cast< const uint(*)>(_a[3]))); break;
-        case 54: _t->rebuildBonds(); break;
-        case 55: _t->orientStandard(); break;
-        case 56: { Eigen::Matrix3d _r = _t->rotateCellMatrixToStandardOrientation((*reinterpret_cast< const Eigen::Matrix3d(*)>(_a[1])));
+        case 52: _t->reduceToAsymmetricUnit(); break;
+        case 53: _t->wrapAtomsToCell(); break;
+        case 54: _t->buildSuperCell((*reinterpret_cast< const uint(*)>(_a[1])),(*reinterpret_cast< const uint(*)>(_a[2])),(*reinterpret_cast< const uint(*)>(_a[3]))); break;
+        case 55: _t->rebuildBonds(); break;
+        case 56: _t->orientStandard(); break;
+        case 57: { Eigen::Matrix3d _r = _t->rotateCellMatrixToStandardOrientation((*reinterpret_cast< const Eigen::Matrix3d(*)>(_a[1])));
             if (_a[0]) *reinterpret_cast< Eigen::Matrix3d*>(_a[0]) = _r; }  break;
-        case 57: _t->showPasteDialog((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 58: { bool _r = _t->niggliReduce();
+        case 58: _t->showPasteDialog((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 59: { bool _r = _t->niggliReduce();
             if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
-        case 59: _t->showUnitCellAxes(); break;
-        case 60: _t->hideUnitCellAxes(); break;
-        case 61: _t->refreshEditors_(); break;
-        case 62: _t->actionPerceiveSpacegroup(); break;
-        case 63: _t->actionSetSpacegroup(); break;
-        case 64: _t->actionFillUnitCell(); break;
-        case 65: _t->actionSymmetrizeCrystal(); break;
-        case 66: _t->actionPrimitiveReduce(); break;
-        case 67: _t->actionNiggliReduce(); break;
-        case 68: _t->actionToggleUnitCell(); break;
-        case 69: _t->actionBuildSlab(); break;
-        case 70: _t->actionPasteCrystal(); break;
-        case 71: _t->actionToggleEditors(); break;
-        case 72: _t->actionToggleProperties(); break;
-        case 73: _t->actionWrapAtoms(); break;
-        case 74: _t->actionTranslateAtoms(); break;
-        case 75: _t->actionViewOptions(); break;
-        case 76: _t->actionOrientStandard(); break;
-        case 77: _t->actionScaleToVolume(); break;
-        case 78: _t->actionUnitsLengthAngstrom(); break;
-        case 79: _t->actionUnitsLengthBohr(); break;
-        case 80: _t->actionUnitsLengthNanometer(); break;
-        case 81: _t->actionUnitsLengthPicometer(); break;
-        case 82: _t->actionUnitsAngleDegree(); break;
-        case 83: _t->actionUnitsAngleRadian(); break;
-        case 84: _t->actionCoordsCart(); break;
-        case 85: _t->actionCoordsFrac(); break;
-        case 86: _t->actionCoordsPreserveCart(); break;
-        case 87: _t->actionCoordsPreserveFrac(); break;
-        case 88: _t->actionMatrixCart(); break;
-        case 89: _t->actionMatrixFrac(); break;
-        case 90: _t->actionMatrixRowVectors(); break;
-        case 91: _t->actionMatrixColumnVectors(); break;
-        case 92: _t->cacheFractionalCoordinates(); break;
-        case 93: _t->restoreFractionalCoordinates(); break;
+        case 60: _t->showUnitCellAxes(); break;
+        case 61: _t->hideUnitCellAxes(); break;
+        case 62: _t->refreshEditors_(); break;
+        case 63: _t->actionPerceiveSpacegroup(); break;
+        case 64: _t->actionSetSpacegroup(); break;
+        case 65: _t->actionFillUnitCell(); break;
+        case 66: _t->actionReduceToAsymmetricUnit(); break;
+        case 67: _t->actionSymmetrizeCrystal((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 68: _t->actionSymmetrizeCrystal(); break;
+        case 69: _t->actionPrimitiveReduce(); break;
+        case 70: _t->actionNiggliReduce(); break;
+        case 71: _t->actionToggleUnitCell(); break;
+        case 72: _t->actionBuildSlab(); break;
+        case 73: _t->actionPasteCrystal(); break;
+        case 74: _t->actionToggleEditors(); break;
+        case 75: _t->actionToggleProperties(); break;
+        case 76: _t->actionWrapAtoms(); break;
+        case 77: _t->actionTranslateAtoms(); break;
+        case 78: _t->actionViewOptions(); break;
+        case 79: _t->actionOrientStandard(); break;
+        case 80: _t->actionScaleToVolume(); break;
+        case 81: _t->actionUnitsLengthAngstrom(); break;
+        case 82: _t->actionUnitsLengthBohr(); break;
+        case 83: _t->actionUnitsLengthNanometer(); break;
+        case 84: _t->actionUnitsLengthPicometer(); break;
+        case 85: _t->actionUnitsAngleDegree(); break;
+        case 86: _t->actionUnitsAngleRadian(); break;
+        case 87: _t->actionCoordsCart(); break;
+        case 88: _t->actionCoordsFrac(); break;
+        case 89: _t->actionCoordsPreserveCart(); break;
+        case 90: _t->actionCoordsPreserveFrac(); break;
+        case 91: _t->actionMatrixCart(); break;
+        case 92: _t->actionMatrixFrac(); break;
+        case 93: _t->actionMatrixRowVectors(); break;
+        case 94: _t->actionMatrixColumnVectors(); break;
+        case 95: _t->actionSpgTolerance(); break;
+        case 96: _t->cacheFractionalCoordinates(); break;
+        case 97: _t->restoreFractionalCoordinates(); break;
         default: ;
         }
     }
@@ -367,9 +378,9 @@ int Avogadro::CrystallographyExtension::qt_metacall(QMetaObject::Call _c, int _i
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 94)
+        if (_id < 98)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 94;
+        _id -= 98;
     }
     return _id;
 }
