@@ -6,7 +6,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "../../../../src/avogadro-1.1.1/libavogadro/src/extensions/networkfetchextension.h"
+#include "../../../../src/avogadro-1.2.0/libavogadro/src/extensions/networkfetchextension.h"
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'networkfetchextension.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 63
@@ -22,7 +22,7 @@ static const uint qt_meta_data_Avogadro__NetworkFetchExtension[] = {
        6,       // revision
        0,       // classname
        0,    0, // classinfo
-       2,   14, // methods
+       3,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -32,6 +32,7 @@ static const uint qt_meta_data_Avogadro__NetworkFetchExtension[] = {
  // slots: signature, parameters, type, tag, flags
       42,   33,   32,   32, 0x0a,
       65,   32,   32,   32, 0x08,
+     124,  100,   95,   32, 0x08,
 
        0        // eod
 };
@@ -39,7 +40,9 @@ static const uint qt_meta_data_Avogadro__NetworkFetchExtension[] = {
 static const char qt_meta_stringdata_Avogadro__NetworkFetchExtension[] = {
     "Avogadro::NetworkFetchExtension\0\0"
     "molecule\0setMolecule(Molecule*)\0"
-    "replyFinished(QNetworkReply*)\0"
+    "replyFinished(QNetworkReply*)\0QUrl\0"
+    "possibleRedirect,oldURL\0"
+    "checkRedirect(QUrl,QUrl)\0"
 };
 
 void Avogadro::NetworkFetchExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
@@ -50,6 +53,8 @@ void Avogadro::NetworkFetchExtension::qt_static_metacall(QObject *_o, QMetaObjec
         switch (_id) {
         case 0: _t->setMolecule((*reinterpret_cast< Molecule*(*)>(_a[1]))); break;
         case 1: _t->replyFinished((*reinterpret_cast< QNetworkReply*(*)>(_a[1]))); break;
+        case 2: { QUrl _r = _t->checkRedirect((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2])));
+            if (_a[0]) *reinterpret_cast< QUrl*>(_a[0]) = _r; }  break;
         default: ;
         }
     }
@@ -87,9 +92,9 @@ int Avogadro::NetworkFetchExtension::qt_metacall(QMetaObject::Call _c, int _id,
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 2)
+        if (_id < 3)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 2;
+        _id -= 3;
     }
     return _id;
 }
